package com.kamco.cd.kamcoback.postgres.repository.Inference;

import com.kamco.cd.kamcoback.postgres.entity.MapSheetAnalDataInferenceGeomEntity;
import java.util.List;

public interface InferenceResultRepositoryCustom {

  int upsertGroupsFromMapSheetAnal();

  int upsertGroupsFromInferenceResults();

  int upsertGeomsFromInferenceResults();

  List<Long> findPendingDataUids(int limit);

  int resetInferenceCreated(Long dataUid);

  int markInferenceCreated(Long dataUid);

  int resetGeomCreatedByDataUid(Long dataUid);

  int markGeomCreatedByGeoUids(List<Long> geoUids);

  List<MapSheetAnalDataInferenceGeomEntity> findGeomEntitiesByDataUid(Long dataUid, int limit);
}
